Stan Math Library: stan/math/fwd/scal/fun/inv_sqrt.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

inv_sqrt.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_SCAL_FUN_INV_SQRT_HPP
2 #define STAN_MATH_FWD_SCAL_FUN_INV_SQRT_HPP
3
4 #include <stan/math/fwd/core.hpp>
5
6 #include <boost/math/tools/promotion.hpp>
7
8 namespace stan {
9
10 namespace math {
11
12 template <typename T>
13 inline
14 fvar<T>
15 inv_sqrt(const fvar<T>& x) {
16 using std::sqrt;
17 T sqrt_x(sqrt(x.val_));
18 return fvar<T>(1 / sqrt_x, -0.5 * x.d_ / (x.val_ * sqrt_x));
19 }
20 }
21 }
22 #endif
core.hpp
stan::math::inv_sqrt
fvar< T > inv_sqrt(const fvar< T > &x)
Definition: inv_sqrt.hpp:15
stan::math::fvar::d_
T d_
Definition: fvar.hpp:15
stan::math::sqrt
fvar< T > sqrt(const fvar< T > &x)
Definition: sqrt.hpp:15
stan
Definition: log_sum_exp.hpp:8
stan::math::fvar::val_
T val_
Definition: fvar.hpp:14
stan::math::fvar
Definition: fvar.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.